<!--📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛

Oh, hi there! 😄

To make our work more accessible, we recommend you to choose any of our available issue templates rather than using (this) a blank template.

To expedite issue processing, please search open and closed issues before submitting a new one.
Please read our Rules of Conduct at this repository's `.github/CODE_OF_CONDUCT.md`

📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛-->

# **Blank Issue Report**

## **Describe the issue**
<!-- A clear and concise description of the problem. -->

*

---

### **Media prove**
<!-- If applicable, add screenshots or videos to help explain your problem. -->

---

### **Your environment**

<!-- use all the applicable bulleted list elements for this specific issue,
and remove all the bulleted list elements that are not relevant for this issue. -->

* OS: <!--[e.g. Ubuntu 5.4.0-26-generic x86_64 / Windows 1904 ...]-->
* Python version:
* Pip version:

---

### **Additional context**
<!-- Add any other context or additional information about the issue here.-->

*
